#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os
import argparse

from fmtomo_teleseismic_utils import setup_fmtomo_sim

#setup_fmtomo_sim('/data/AlpArray_Data/dmt_database/', '//data/AlpArray_Data/fmtomo/v6_S/crust_incl_hf_sm_FIX_DTS_grad_sm30_dm10')
#setup_fmtomo_sim('/rscratch/minos13/marcel/dmt_database_test_event', '/home/marcel/marcel_scratch/alparray/fmtomo_traveltime_tomo/alparray_0/')
#setup_fmtomo_sim('/rscratch/minos13/marcel/dmt_database_m7', '/home/marcel/marcel_scratch/alparray/fmtomo_traveltime_tomo/alparray_0/')
#setup_fmtomo_sim('/rscratch/minos22/marcel/dmt_database_m7', '/rscratch/minos22/marcel/alparray/fmtomo_traveltime_tomo/alparray_0_receiver_elev_zero_smaller_box')
#setup_fmtomo_sim('/rscratch/minos22/marcel/dmt_database_m7', '/rscratch/minos22/marcel/alparray/fmtomo_traveltime_tomo/alparray_0_receiver_elev_zero_bigger_box')
#setup_fmtomo_sim('/rscratch/minos22/marcel/dmt_database_m7', '/rscratch/minos22/marcel/alparray/fmtomo_traveltime_tomo/alparray_0_receiver_elev_zero_shallow_box')
#setup_fmtomo_sim('/rscratch/minos22/marcel/dmt_database_m7', '/rscratch/minos22/marcel/alparray/fmtomo_traveltime_tomo/alparray_0_receiver_elev_zero_finer_interface')
#setup_fmtomo_sim('/rscratch/minos22/marcel/dmt_database_m7', '/rscratch/minos22/marcel/alparray/fmtomo_traveltime_tomo/alparray_0_receiver_elev_zero_bigger_box_equal_dist_2')

#pgrid = Propgrid('/rscratch/minos22/marcel/alparray/fmtomo_traveltime_tomo/alparray_0/propgrid.in')

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='Prepare grid for fm3d teleseismic hybrid calculation.')
    parser.add_argument('dmt_path', help='path containing dmt_database with PyLoT picks')
    parser.add_argument('fmtomodir', help='path containing fm3d output')
    parser.add_argument('fname_extension', help='filename extension of pick files')
    parser.add_argument('--blacklist', default=None,
                        help='station blacklist file (csv). After first line: NW_id,ST_id in each line')
    parser.add_argument('--no_write_init_nodes', default=False, action='store_true',
                        help='do not calculate and write init nodes')
    parser.add_argument('--no_recalculate_init_nodes', default=False, action='store_true',
                        help='do not recalculate init nodes if nodes file exists')
    parser.add_argument('-n', dest='ncores', default=None, help='number of cores for multiprocessing')
    parser.add_argument('--model', default='ak135')
    parser.add_argument('--s_phase', default=False, action='store_true')

    args = parser.parse_args()

    database_path = os.path.abspath(args.dmt_path)
    fmtomodir = os.path.abspath(args.fmtomodir)
    if args.ncores is not None:
        ncores = int(args.ncores)
    else:
        ncores = None
    fname_extension = args.fname_extension

    sub_phases = {'P': ['P', 'PKP'], 'S': ['S', 'SKS']}
    phase_types = ['P']
    if args.s_phase:
        phase_types.append('S')

    setup_fmtomo_sim(database_path, fmtomodir, fname_extension, sub_phases, ncores=ncores, check_notesfile=False,
                     model=args.model, fname_station_blacklist=args.blacklist,
                     no_write_init_nodes=args.no_write_init_nodes,
                     no_recalculate_init_nodes=args.no_recalculate_init_nodes, phase_types=phase_types)
