import os
import numpy as np
import matplotlib.pyplot as plt

fpaths = ['/data/AlpArray_Data/fmtomo/v6/fwi_model_wolfgang_test',
          '/data/AlpArray_Data/fmtomo/v6/final']
arr_path_ref = 'rtimes_tele.dat'

iterations = [0, 1, 2, 3, 4]
labels = ['rel_1d'] + [f'rel_it{it}' for it in iterations]

colors = plt.get_cmap('viridis')(np.linspace(0,1, len(iterations)))
colors = np.vstack(((.5, .5, .5, 1), colors))

axes = []
for fpath in fpaths:
    rtimes = np.genfromtxt(os.path.join(fpath, arr_path_ref))[:, 4]
    otimes = np.genfromtxt(os.path.join(fpath, 'otimes.dat'), skip_header=1)[:, 4]

    res = np.empty((len(rtimes), len(iterations) + 1))

    res[:, 0] = otimes # = otimes + rtimes - rtimes

    for index, itr in enumerate(iterations):
        arr_path = f'it_{itr}/arrivals.dat'

        arrivals = np.genfromtxt(os.path.join(fpath, arr_path))[:, 4]
        res[:, index + 1] = (otimes + rtimes) - arrivals # otimes (rel) + rtimes => otimes (abs)

    fig = plt.figure()
    ax = fig.add_subplot(111)
    axes.append(ax)
    ax.hist(res, bins=np.linspace(-5, 5, 50), rwidth=0.9, color=colors, label=labels)
    ax.set_xlim(-1.5, 1.5)
    plt.title(fpath)

    ax.legend()

ylim_max = max([ax.get_ylim()[1] for ax in axes])
for ax in axes:
    ax.set_ylim(0, ylim_max)

plt.show()
